@@ -40,6 +40,36 @@ class TestAdminAPI(object):
             data=None,
         )
 
+    @mock.patch('requests.request')
+    def test_get_data_set_by_name(self, mock_request):
+        mock_request.__name__ = 'request'
+        api = AdminAPI('http://admin.api', None)
+        data_set = api.get_data_set_by_name('foo_bar')
+
+        mock_request.assert_called_with(
+            'GET',
+            'http://admin.api/data-sets/foo_bar',
+            headers=match_equality(has_entries({
+                'Accept': 'application/json',
+            })),
+            data=None,
+        )
+
+    @mock.patch('requests.request')
+    def test_get_data_set_transforms(self, mock_request):
+        mock_request.__name__ = 'request'
+        api = AdminAPI('http://admin.api', None)
+        data_set = api.get_data_set_transforms('foo_bar')
+
+        mock_request.assert_called_with(
+            'GET',
+            'http://admin.api/data-sets/foo_bar/transform',
+            headers=match_equality(has_entries({
+                'Accept': 'application/json',
+            })),
+            data=None,
+        )
+
     @mock.patch('requests.request')
     def test_make_sure_returns_response(self, mock_request):
         response = Response()
