@@ -306,3 +306,40 @@ class TestDataSet(object):
 
         assert_raises(HTTPError, data_set.post, [{'key': 'foo'}])
         eq_(mock_request.call_count, 5)
+
+    def test_to_query_string_with_empty(self):
+        data_set = DataSet('', None)
+        eq_(data_set._to_query_string({}), '')
+
+    def test_to_query_string_with_params(self):
+        data_set = DataSet('', None)
+        eq_(data_set._to_query_string({
+            'foo': 'bar',
+            'bar': 'foo',
+        }), '?foo=bar&bar=foo')
+
+    def test_to_query_string_with_param_list(self):
+        data_set = DataSet('', None)
+        eq_(data_set._to_query_string({
+            'foo': ['bar1', 'bar2'],
+        }), '?foo=bar1&foo=bar2')
+
+    @mock.patch('requests.request')
+    def test_get_data_set_with_params(self, mock_request):
+        mock_request.__name__ = 'request'
+        data_set = DataSet.from_group_and_type(
+            # bit of a gotcha in the /data here
+            'http://dropthebase.com/data',
+            'famous-knights',
+            'dragons-killed',
+            token='token',
+        )
+
+        data_set.get(query_parameters={'foo': 'bar'})
+
+        mock_request.assert_called_with(
+            'GET',
+            'http://dropthebase.com/data/famous-knights/dragons-killed?foo=bar',
+            headers=mock.ANY,
+            data=mock.ANY,
+        )
